@@ -167,15 +167,17 @@ namespace LongoMatch.Gui
 			return;
 			
 			/* stopping and closing capturer */
-			capturer.Stop();
-			capturer.Close();
-			if (capturerType == CapturerType.Live){
-				/* release and dispose live capturer */
-				capturer.Error -= OnError;
-				capturer.DeviceChange += OnDeviceChange;
-				capturerhbox.Remove(capturer as Gtk.Widget);
-				capturer.Dispose();
-			}
+			try {
+				capturer.Stop();
+				capturer.Close();
+				if (capturerType == CapturerType.Live){
+					/* release and dispose live capturer */
+					capturer.Error -= OnError;
+					capturer.DeviceChange += OnDeviceChange;
+					capturerhbox.Remove(capturer as Gtk.Widget);
+					capturer.Dispose();
+				}
+			} catch (Exception e) {}
 			capturer = null;
 		}
 		
@@ -299,7 +301,7 @@ namespace LongoMatch.Gui
 				                                     MessageType.Question, ButtonsType.Ok,
 				                                     Catalog.GetString("Device disconnected. " +
 				                                     	"The capture will be paused"));
-				md.Icon=Stetic.IconLoader.LoadIcon(md, "longomatch", Gtk.IconSize.Dialog, 48);
+				md.Icon=Stetic.IconLoader.LoadIcon(md, "longomatch", Gtk.IconSize.Dialog);
 				md.Run();
 				md.Destroy();			
 			} else {
@@ -308,7 +310,7 @@ namespace LongoMatch.Gui
 				                                     MessageType.Question, ButtonsType.YesNo,
 				                                     Catalog.GetString("Device reconnected." +
 				                                     	"Do you want to restart the capture?"));
-				md.Icon=Stetic.IconLoader.LoadIcon(md, "longomatch", Gtk.IconSize.Dialog, 48);
+				md.Icon=Stetic.IconLoader.LoadIcon(md, "longomatch", Gtk.IconSize.Dialog);
 				if (md.Run() == (int)ResponseType.Yes){
 					Console.WriteLine ("Accepted to toggle pause");
 					TogglePause();
